@@ -1,4 +1,4 @@
-/* Copyright (C) 1999-2003, 2005-2006, 2008-2009 Free Software Foundation, Inc.
+/* Copyright (C) 1999-2019 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Library.
 
    The GNU LIBICONV Library is free software; you can redistribute it
@@ -13,15 +13,14 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the GNU LIBICONV Library; see the file COPYING.LIB.
-   If not, write to the Free Software Foundation, Inc., 51 Franklin Street,
-   Fifth Floor, Boston, MA 02110-1301, USA.  */
+   If not, see <https://www.gnu.org/licenses/>.  */
 
 /* When installed, this file is called "iconv.h". */
 
 #ifndef _LIBICONV_H
 #define _LIBICONV_H
 
-#define _LIBICONV_VERSION 0x010D    /* version number: (major<<8) + minor */
+#define _LIBICONV_VERSION 0x0110    /* version number: (major<<8) + minor */
 extern  int _libiconv_version; /* Likewise */
 
 /* We would like to #include any system header file which could define
@@ -89,6 +88,11 @@ extern size_t iconv (iconv_t cd,  char* * inbuf, size_t *inbytesleft, char* * ou
 extern int iconv_close (iconv_t cd);
 
 
+#ifdef __cplusplus
+}
+#endif
+
+
 #ifndef LIBICONV_PLUG
 
 /* Nonstandard extensions. */
@@ -106,6 +110,10 @@ extern int iconv_close (iconv_t cd);
 #include <wchar.h>
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* A type that holds all memory needed by a conversion descriptor.
    A pointer to such an object can be used as an iconv_t. */
 typedef struct {
@@ -221,14 +229,13 @@ extern const char * iconv_canonicalize (const char * name);
    prefixes should be directory names without trailing slash (i.e. use ""
    instead of "/").  */
 extern void libiconv_set_relocation_prefix (const char *orig_prefix,
-					    const char *curr_prefix);
-
-#endif
-
+                                            const char *curr_prefix);
 
 #ifdef __cplusplus
 }
 #endif
 
+#endif
+
 
 #endif /* _LIBICONV_H */
